# NakalaPycon

Librairie Python pour interagir avec Nakala (Nakala : entrepôt de données de recherche en SHS développé par Huma-Num).

## Cas d'usages

### 1. Intéragir avec Nakala depuis un notebook Jupyter

- Générer un rapport de donnnées intéractif en ciblant une collection depuis un notebook jupyter.


### 2. Développer sa chaîne de traitement semi-automatisé intégrant Nakala dans la chaîne

- Fabriquer son outils de dépôt et MAJ "sur-mesure" intégrant Nakala.

